AmlError

Enum AmlError 

pub enum AmlError {
Show 47 variants UnexpectedEndOfStream, UnexpectedByte(u8), MalformedStream, InvalidNameSeg, InvalidPkgLength, InvalidFieldFlags, UnterminatedStringConstant, InvalidStringConstant, InvalidRegionSpace(u8), MalformedPackage, MalformedBuffer, WrongParser, FatalError, EmptyNamesAreInvalid, InvalidNormalizedName(AmlName), RootHasNoParent, LevelDoesNotExist(AmlName), ValueDoesNotExist(AmlName), NameCollision(AmlName), TriedToRemoveRootNamespace, NotExecutingControlMethod, InvalidArgAccess(u8), InvalidLocalAccess(u8), TooManyArgs, BreakInInvalidPosition, ContinueInInvalidPosition, PrtInvalidAddress, PrtInvalidPin, PrtInvalidSource, PrtInvalidGsi, PrtNoEntry, ReservedResourceType, ResourceDescriptorTooShort, ResourceDescriptorTooLong, UnexpectedResourceType, IncompatibleValueConversion { current: AmlType, target: AmlType, }, InvalidStatusObject, InvalidShiftLeft, InvalidShiftRight, FieldRegionIsNotOpRegion, FieldInvalidAddress, FieldInvalidAccessSize, TypeCannotBeCompared(AmlType), TypeCannotBeSliced(AmlType), TypeCannotBeWrittenToBufferField(AmlType), BufferFieldIndexesOutOfBounds, Unimplemented,
}
Used when an AmlContext encounters an error.

Variants



UnexpectedEndOfStream



UnexpectedByte(u8)



MalformedStream

Produced when the stream evaluates to something other than nothing or an error.



InvalidNameSeg



InvalidPkgLength



InvalidFieldFlags



UnterminatedStringConstant



InvalidStringConstant



InvalidRegionSpace(u8)



MalformedPackage

Produced when a DefPackage contains a different number of elements to the package’s length.



MalformedBuffer

Produced when a DefBuffer contains more bytes that its size.



WrongParser

Emitted by a parser when it’s clear that the stream doesn’t encode the object parsed by that parser (e.g. the wrong opcode starts the stream). This is handled specially by some parsers such as or and choice!.



FatalError

Returned when a DefFatal op is encountered. This is separately reported using Handler::handle_fatal_error.



EmptyNamesAreInvalid



InvalidNormalizedName(AmlName)

Produced when trying to normalize a path that does not point to a valid level of the namespace. E.g. \_SB.^^PCI0 goes above the root of the namespace. The contained value is the name that normalization was attempted upon.



RootHasNoParent



LevelDoesNotExist(AmlName)

Produced when a sub-level or value is added to a level that has not yet been added to the namespace. The AmlName is the name of the entire sub-level/value.



ValueDoesNotExist(AmlName)



NameCollision(AmlName)

Produced when two values with the same name are added to the namespace.



TriedToRemoveRootNamespace



NotExecutingControlMethod

Produced when AML tries to do something only possible in a control method (e.g. read from an argument) when there’s no control method executing.



InvalidArgAccess(u8)

Produced when a method accesses an argument it does not have (e.g. a method that takes 2 arguments accesses Arg4). The inner value is the number of the argument accessed.



InvalidLocalAccess(u8)

Produced when a method accesses a local that it has not stored into.



TooManyArgs

Tried to invoke a method with too many arguments.



BreakInInvalidPosition

A DefBreak operation was performed outside of a DefWhile or DefSwitch.



ContinueInInvalidPosition

A DefContinue operation was performed outside of a DefWhile.



PrtInvalidAddress



PrtInvalidPin



PrtInvalidSource



PrtInvalidGsi



PrtNoEntry

Produced when the PRT doesn’t contain an entry for the requested address + pin



ReservedResourceType



ResourceDescriptorTooShort



ResourceDescriptorTooLong



UnexpectedResourceType



IncompatibleValueConversion

Fields

current: AmlType
target: AmlType


InvalidStatusObject



InvalidShiftLeft



InvalidShiftRight



FieldRegionIsNotOpRegion



FieldInvalidAddress



FieldInvalidAccessSize



TypeCannotBeCompared(AmlType)



TypeCannotBeSliced(AmlType)

Produced when the Mid operator is applied to a value of a type other than Buffer or String.



TypeCannotBeWrittenToBufferField(AmlType)



BufferFieldIndexesOutOfBounds



Unimplemented

Unimplemented functionality - return error rather than abort