pub enum DebugVerbosity {
None,
Scopes,
AllScopes,
All,
}Expand description
Describes how much debug information the parser should emit. Set the “maximum” expected verbosity in
the context’s debug_verbosity - everything will be printed that is less or equal in ‘verbosity’.
Variants
None
Print no debug information
Scopes
Print heads and tails when entering and leaving scopes of major objects, but not more minor ones.
AllScopes
Print heads and tails when entering and leaving scopes of all objects.
All
Print heads and tails of all objects, and extra debug information as it’s parsed.