pub struct StatusObject {
pub present: bool,
pub enabled: bool,
pub show_in_ui: bool,
pub functional: bool,
pub battery_present: bool,
}Expand description
Representation of the return value of a _STA method, which represents the status of an object. It must be
evaluated, if present, before evaluating the _INI method for an device.
The Default implementation of this type is the correct value to use if a device doesn’t have a _STA object
to evaluate.
Fields
present: boolWhether the device is physically present. If this is false, enabled should also be false (i.e. a
device that is not present can’t be enabled). However, this is not enforced here if the firmware is doing
something wrong.
enabled: boolWhether the device is enabled. Both present and enabled must be true for the device to decode its
hardware resources.
show_in_ui: boolfunctional: boolbattery_present: boolOnly applicable for Control Method Battery Devices (PNP0C0A). For all other devices, ignore this value.