pub struct Namespace { /* private fields */ }Implementations
Sourceimpl Namespace
impl Namespace
pub fn new() -> Namespace
Sourcepub fn add_level(
&mut self,
path: AmlName,
typ: LevelType,
) -> Result<(), AmlError>
pub fn add_level( &mut self, path: AmlName, typ: LevelType, ) -> Result<(), AmlError>
Add a new level to the namespace. A “level” is named by a single NameSeg, and can contain values, and
also other further sub-levels. Once a level has been created, AML values can be added to it with
add_value.
Note
At first glance, you might expect DefDevice to add a value of type Device. However, because all
Devices do is hold other values, we model them as namespace levels, and so they must be created
accordingly.
pub fn remove_level(&mut self, path: AmlName) -> Result<(), AmlError>
Sourcepub fn add_value(
&mut self,
path: AmlName,
value: AmlValue,
) -> Result<AmlHandle, AmlError>
pub fn add_value( &mut self, path: AmlName, value: AmlValue, ) -> Result<AmlHandle, AmlError>
Add a value to the namespace at the given path, which must be a normalized, absolute AML
name. If you want to add at a path relative to a given scope, use add_at_resolved_path
instead.
Sourcepub fn add_value_at_resolved_path(
&mut self,
path: AmlName,
scope: &AmlName,
value: AmlValue,
) -> Result<AmlHandle, AmlError>
pub fn add_value_at_resolved_path( &mut self, path: AmlName, scope: &AmlName, value: AmlValue, ) -> Result<AmlHandle, AmlError>
Helper method for adding a value to the namespace at a path that is relative to the given scope. This operation involves a lot of error handling in parts of the parser, so is encapsulated here.
Sourcepub fn add_alias_at_resolved_path(
&mut self,
path: AmlName,
scope: &AmlName,
target: AmlName,
) -> Result<AmlHandle, AmlError>
pub fn add_alias_at_resolved_path( &mut self, path: AmlName, scope: &AmlName, target: AmlName, ) -> Result<AmlHandle, AmlError>
Add an alias for an existing name. The alias will refer to the same value as the original, and the fact that the alias exists is forgotten.
pub fn get(&self, handle: AmlHandle) -> Result<&AmlValue, AmlError>
pub fn get_mut(&mut self, handle: AmlHandle) -> Result<&mut AmlValue, AmlError>
pub fn get_handle(&self, path: &AmlName) -> Result<AmlHandle, AmlError>
pub fn get_by_path(&self, path: &AmlName) -> Result<&AmlValue, AmlError>
pub fn get_by_path_mut( &mut self, path: &AmlName, ) -> Result<&mut AmlValue, AmlError>
Sourcepub fn search(
&self,
path: &AmlName,
starting_scope: &AmlName,
) -> Result<(AmlName, AmlHandle), AmlError>
pub fn search( &self, path: &AmlName, starting_scope: &AmlName, ) -> Result<(AmlName, AmlHandle), AmlError>
Search for an object at the given path of the namespace, applying the search rules described in 5.3 of the ACPI specification, if they are applicable. Returns the resolved name, and the handle of the first valid object, if found.
pub fn search_for_level( &self, level_name: &AmlName, starting_scope: &AmlName, ) -> Result<AmlName, AmlError>
Sourcepub fn traverse<F>(&mut self, f: F) -> Result<(), AmlError>
pub fn traverse<F>(&mut self, f: F) -> Result<(), AmlError>
Traverse the namespace, calling f on each namespace level. f returns a Result<bool, AmlError> -
errors terminate the traversal and are propagated, and the bool on the successful path marks whether the
children of the level should also be traversed.